pub(crate) enum InputType {
Show 22 variants
Button(ButtonInputType),
Checkbox(CheckboxInputType),
Color(ColorInputType),
Date(DateInputType),
DatetimeLocal(DatetimeLocalInputType),
Email(EmailInputType),
File(FileInputType),
Hidden(HiddenInputType),
Image(ImageInputType),
Month(MonthInputType),
Number(NumberInputType),
Password(PasswordInputType),
Radio(RadioInputType),
Range(RangeInputType),
Reset(ResetInputType),
Search(SearchInputType),
Submit(SubmitInputType),
Tel(TelInputType),
Text(TextInputType),
Time(TimeInputType),
Url(UrlInputType),
Week(WeekInputType),
}Expand description
Variants
Button(ButtonInputType)
Checkbox(CheckboxInputType)
Color(ColorInputType)
Date(DateInputType)
DatetimeLocal(DatetimeLocalInputType)
Email(EmailInputType)
File(FileInputType)
Hidden(HiddenInputType)
Image(ImageInputType)
Month(MonthInputType)
Number(NumberInputType)
Password(PasswordInputType)
Radio(RadioInputType)
Range(RangeInputType)
Reset(ResetInputType)
Search(SearchInputType)
Submit(SubmitInputType)
Tel(TelInputType)
Text(TextInputType)
Time(TimeInputType)
Url(UrlInputType)
Week(WeekInputType)
Implementations
Sourceimpl InputType
impl InputType
pub(crate) fn new_from_atom(value: &Atom) -> Self
pub(crate) fn new_text() -> Self
pub(crate) fn as_specific(&self) -> &dyn SpecificInputType
Sourcepub(crate) fn is_textual(&self) -> bool
pub(crate) fn is_textual(&self) -> bool
Defines which input type that should perform like a text input, specifically when it is interacting with JS. Note that Password is not included here since it is handled slightly differently, with placeholder characters shown rather than the underlying value.
pub(crate) fn is_textual_or_password(&self) -> bool
Sourcepub(crate) fn has_periodic_domain(&self) -> bool
pub(crate) fn has_periodic_domain(&self) -> bool
pub(crate) fn as_str(&self) -> &str